# PrYmer
Decided to write my own thingy to automatically generate/test primer sequences.


    usage: PrYmer.py [-h] [-l, LENGTH] sequences

    Return primers for given input sequences.
    
    positional arguments:
      sequences             The sequence file to design primers for. It is assumed
                            all sequences are provided 5' -> 3'
    
    optional arguments:
      -h, --help            show this help message and exit
      -l, LENGTH, --length LENGTH
                            Desired length of primer sequences.

